@@ -76,14 +76,14 @@ def _read_metric(path, fs, rev, **kwargs):
 
 
 def _read_metrics(repo, metrics, rev, onerror=None):
-    fs = RepoFileSystem(repo)
+    fs = RepoFileSystem(repo=repo)
 
     res = {}
     for metric in metrics:
         if not fs.isfile(metric):
             continue
 
-        res[fs.path.relpath(metric, os.getcwd())] = _read_metric(
+        res[os.path.relpath(metric, os.getcwd())] = _read_metric(
             metric, fs, rev, onerror=onerror
         )
 
